<template lang="pug">
v-datepicker(
    v-model="date" 
    :min-date="minDate" 
    :max-date="maxDate"
    :disabled-dates="disabledDates" 
    :available-dates="availableDates"
    :update-on-input="false"
    :is-required="isRequired"
    :is-expanded="isExpanded"
    @input="onInput"
    @dayclick="onDayClick"
)
    template(v-slot="{ inputValue, togglePopover }" v-if="!showCalendar")
        app-input(
            icon="today" 
            is-datepicker
            :is-invalid="isInvalid"
            :disabled="disabled"
            :value="inputValue" 
            :loading="loading"
            :placeholder="placeholder" 
            @click="onClickInput(togglePopover)" 
        )
</template>

<script>
import AppInput from '../AppInput'
export default {
    name: 'AppDatepicker',
    components: {
        AppInput,
    },
    data: () => ({
        date: null,
    }),
    props: {
        value: {
            type: Date,
            default: null,
        },
        loading: {
            type: Boolean,
            default: false,
        },
        minDate: {
            type: Date,
            default: null,
        },
        maxDate: {
            type: Date,
            default: null
        },
        disabledDates: {
            type: Array,
            default: () => [],
        },
        availableDates: {
            type: Array,
            default: () => []
        },
        isRequired: {
            type: Boolean,
            default: false,
        },
        placeholder: {
            type: String,
            default: null,
        },
        showOnClick: {
            type: Boolean,
            default: true,
        },
        disabled: {
            type: Boolean,
            default: false,
        },
        showCalendar: {
            type: Boolean,
            default: false,
        },
        isExpanded: {
            type: Boolean,
            default: false,
        },
        isInvalid: {
            type: Boolean,
            default: false,
        },
    },
    created() {
        if (this.value) this.date = this.value
    },
    watch: {
        value(newValue) {
            if (newValue) this.date = newValue
        },
    },
    methods: {
        onClickInput(togglePopover) {
            if (!this.showOnClick) {
                this.$emit('click', togglePopover)
                return
            }
            togglePopover()
        },
        onInput(event) {
            this.$emit('input', event)
        },
        onDayClick(event) {
            this.$emit('dayclick', event)
        },
    },
}
</script>
<style lang="scss" src="./index.scss"></style>
